Models
======

Pydantic models for API entities.

.. module:: numistalib.models

Base Models
-----------

.. automodule:: numistalib.models.base.base_model
   :members:
   :undoc-members:
   :show-inheritance:

Types
-----

.. automodule:: numistalib.models.types
   :members:
   :undoc-members:
   :show-inheritance:

Catalogues
----------

.. automodule:: numistalib.models.catalogues
   :members:
   :undoc-members:
   :show-inheritance:

Issuers
-------

.. automodule:: numistalib.models.issuer
   :members:
   :undoc-members:
   :show-inheritance:

Issues
------

.. automodule:: numistalib.models.issues
   :members:
   :undoc-members:
   :show-inheritance:

Mints
-----

.. automodule:: numistalib.models.mints
   :members:
   :undoc-members:
   :show-inheritance:

Collections
-----------

.. automodule:: numistalib.models.collections
   :members:
   :undoc-members:
   :show-inheritance:

Literature
----------

.. automodule:: numistalib.models.literature
   :members:
   :undoc-members:
   :show-inheritance:

Prices
------

.. automodule:: numistalib.models.prices
   :members:
   :undoc-members:
   :show-inheritance:

Users
-----

.. automodule:: numistalib.models.users
   :members:
   :undoc-members:
   :show-inheritance:

Currency
--------

.. automodule:: numistalib.models.currency
   :members:
   :undoc-members:
   :show-inheritance:

References
----------

.. automodule:: numistalib.models.references
   :members:
   :undoc-members:
   :show-inheritance:

Errors
------

.. automodule:: numistalib.models.errors
   :members:
   :undoc-members:
   :show-inheritance:

Updates
-------

.. automodule:: numistalib.models.updates
   :members:
   :undoc-members:
   :show-inheritance:
